from django.contrib import admin

from .models import TimelineLog


@admin.register(TimelineLog)
class TimelineLogAdmin(admin.ModelAdmin):
    list_display = ["__str__", "timestamp", "template"]
    list_filter = ["timestamp", "content_type"]
    list_select_related = ["content_type"]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-25 14:14
from __future__ import unicode_literals

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("timeline_logger", "0002_auto_20160624_1045"),
    ]

    operations = [
        migrations.AlterField(
            model_name="timelinelog",
            name="user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-03-13 17:38
from __future__ import unicode_literals

import django.contrib.postgres.fields.jsonb
import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("timeline_logger", "0003_auto_20171025_1414"),
    ]

    operations = [
        migrations.AlterField(
            model_name="timelinelog",
            name="content_type",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="contenttypes.ContentType",
                verbose_name="content type",
            ),
        ),
        migrations.AlterField(
            model_name="timelinelog",
            name="extra_data",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                blank=True, null=True, verbose_name="extra data"
            ),
        ),
        migrations.AlterField(
            model_name="timelinelog",
            name="object_id",
            field=models.TextField(blank=True, null=True, verbose_name="object id"),
        ),
        migrations.AlterField(
            model_name="timelinelog",
            name="timestamp",
            field=models.DateTimeField(auto_now_add=True, verbose_name="timestamp"),
        ),
        migrations.AlterField(
            model_name="timelinelog",
            name="user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to=settings.AUTH_USER_MODEL,
                verbose_name="user",
            ),
        ),
    ]



from __future__ import absolute_import, unicode_literals

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class TimelineLoggerConfig(AppConfig):
    name = "timeline_logger"
    verbose_name = _("Django Timeline Logger")

    def ready(self):
        from . import conf  # noqa



# -*- coding: utf-8 -*-
# Generated by Django 1.9.4 on 2016-06-24 10:45
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("timeline_logger", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="timelinelog",
            options={
                "verbose_name": "timeline log entry",
                "verbose_name_plural": "timeline log entries",
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.4 on 2016-06-15 18:16
from __future__ import unicode_literals

import django.contrib.postgres.fields.jsonb
import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("contenttypes", "0002_remove_content_type_name"),
    ]

    operations = [
        migrations.CreateModel(
            name="TimelineLog",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("object_id", models.PositiveIntegerField()),
                ("timestamp", models.DateTimeField(auto_now_add=True)),
                (
                    "extra_data",
                    django.contrib.postgres.fields.jsonb.JSONField(
                        blank=True, null=True
                    ),
                ),
                (
                    "template",
                    models.CharField(
                        default="timeline_logger/default.txt", max_length=200
                    ),
                ),
                (
                    "content_type",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="contenttypes.ContentType",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        ),
    ]
